@@ -4,7 +4,7 @@ import numpy
 imageAP = argparse.ArgumentParser("Plots the image loaded as dataset to a given axis coordinate dimension.")
 imageAP.add_argument("imageDataset", help="Name of the dataset containing the RGB(A) data. They should be in an unrolled loop.")
 imageAP.add_argument("imageRect", nargs=4, type=float, help="Rectangle for the image to be drawn into, in axes coordinates. (x,y,width,height).")
-imageAP.add_argument("--shape", type=lambda x: list(map(int, x.split(","))), help="Shape of the image, in format width,height.")
+imageAP.add_argument("--shape", type=int, nargs=2, help="Shape of the image, in format width,height.")
 
 def command(axes, datasets, argString):
     args = imageAP.parse_args(argString)
