@@ -3,11 +3,11 @@ import argparse
 
 class ColsReference:
     # Object that ensures that only the converged eigenvalues are read
-    def __init__(self, parserArgs="0"):
+    def __init__(self, parserArgs=["0"]):
         self.argsReader = argparse.ArgumentParser(description="Parses the arguments for the parser itself.")
         self.argsReader.add_argument("--comment", help="Character to be used as indicator of comment. [default : #]", default="#")
         self.argsReader.add_argument("cols", nargs="+", type=int, help="Indices of columns to read.")
-        self.args = self.argsReader.parse_args(parserArgs.split())
+        self.args = self.argsReader.parse_args(parserArgs)
 
     def continueReading(self, line):
         if line[0] == self.args.comment:
